/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include "gf-upower-device-gen.h"

#include <string.h>
#ifdef G_OS_UNIX
#  include <gio/gunixfdlist.h>
#endif

#ifdef G_ENABLE_DEBUG
#define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
#define g_marshal_value_peek_char(v)     g_value_get_schar (v)
#define g_marshal_value_peek_uchar(v)    g_value_get_uchar (v)
#define g_marshal_value_peek_int(v)      g_value_get_int (v)
#define g_marshal_value_peek_uint(v)     g_value_get_uint (v)
#define g_marshal_value_peek_long(v)     g_value_get_long (v)
#define g_marshal_value_peek_ulong(v)    g_value_get_ulong (v)
#define g_marshal_value_peek_int64(v)    g_value_get_int64 (v)
#define g_marshal_value_peek_uint64(v)   g_value_get_uint64 (v)
#define g_marshal_value_peek_enum(v)     g_value_get_enum (v)
#define g_marshal_value_peek_flags(v)    g_value_get_flags (v)
#define g_marshal_value_peek_float(v)    g_value_get_float (v)
#define g_marshal_value_peek_double(v)   g_value_get_double (v)
#define g_marshal_value_peek_string(v)   (char*) g_value_get_string (v)
#define g_marshal_value_peek_param(v)    g_value_get_param (v)
#define g_marshal_value_peek_boxed(v)    g_value_get_boxed (v)
#define g_marshal_value_peek_pointer(v)  g_value_get_pointer (v)
#define g_marshal_value_peek_object(v)   g_value_get_object (v)
#define g_marshal_value_peek_variant(v)  g_value_get_variant (v)
#else /* !G_ENABLE_DEBUG */
/* WARNING: This code accesses GValues directly, which is UNSUPPORTED API.
 *          Do not access GValues directly in your code. Instead, use the
 *          g_value_get_*() functions
 */
#define g_marshal_value_peek_boolean(v)  (v)->data[0].v_int
#define g_marshal_value_peek_char(v)     (v)->data[0].v_int
#define g_marshal_value_peek_uchar(v)    (v)->data[0].v_uint
#define g_marshal_value_peek_int(v)      (v)->data[0].v_int
#define g_marshal_value_peek_uint(v)     (v)->data[0].v_uint
#define g_marshal_value_peek_long(v)     (v)->data[0].v_long
#define g_marshal_value_peek_ulong(v)    (v)->data[0].v_ulong
#define g_marshal_value_peek_int64(v)    (v)->data[0].v_int64
#define g_marshal_value_peek_uint64(v)   (v)->data[0].v_uint64
#define g_marshal_value_peek_enum(v)     (v)->data[0].v_long
#define g_marshal_value_peek_flags(v)    (v)->data[0].v_ulong
#define g_marshal_value_peek_float(v)    (v)->data[0].v_float
#define g_marshal_value_peek_double(v)   (v)->data[0].v_double
#define g_marshal_value_peek_string(v)   (v)->data[0].v_pointer
#define g_marshal_value_peek_param(v)    (v)->data[0].v_pointer
#define g_marshal_value_peek_boxed(v)    (v)->data[0].v_pointer
#define g_marshal_value_peek_pointer(v)  (v)->data[0].v_pointer
#define g_marshal_value_peek_object(v)   (v)->data[0].v_pointer
#define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
#endif /* !G_ENABLE_DEBUG */

typedef struct
{
  GDBusArgInfo parent_struct;
  gboolean use_gvariant;
} _ExtendedGDBusArgInfo;

typedef struct
{
  GDBusMethodInfo parent_struct;
  const gchar *signal_name;
  gboolean pass_fdlist;
} _ExtendedGDBusMethodInfo;

typedef struct
{
  GDBusSignalInfo parent_struct;
  const gchar *signal_name;
} _ExtendedGDBusSignalInfo;

typedef struct
{
  GDBusPropertyInfo parent_struct;
  const gchar *hyphen_name;
  guint use_gvariant : 1;
  guint emits_changed_signal : 1;
} _ExtendedGDBusPropertyInfo;

typedef struct
{
  GDBusInterfaceInfo parent_struct;
  const gchar *hyphen_name;
} _ExtendedGDBusInterfaceInfo;

typedef struct
{
  const _ExtendedGDBusPropertyInfo *info;
  guint prop_id;
  GValue orig_value; /* the value before the change */
} ChangedProperty;

static void
_changed_property_free (ChangedProperty *data)
{
  g_value_unset (&data->orig_value);
  g_free (data);
}

static gboolean
_g_strv_equal0 (gchar **a, gchar **b)
{
  gboolean ret = FALSE;
  guint n;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  if (g_strv_length (a) != g_strv_length (b))
    goto out;
  for (n = 0; a[n] != NULL; n++)
    if (g_strcmp0 (a[n], b[n]) != 0)
      goto out;
  ret = TRUE;
out:
  return ret;
}

static gboolean
_g_variant_equal0 (GVariant *a, GVariant *b)
{
  gboolean ret = FALSE;
  if (a == NULL && b == NULL)
    {
      ret = TRUE;
      goto out;
    }
  if (a == NULL || b == NULL)
    goto out;
  ret = g_variant_equal (a, b);
out:
  return ret;
}

G_GNUC_UNUSED static gboolean
_g_value_equal (const GValue *a, const GValue *b)
{
  gboolean ret = FALSE;
  g_assert (G_VALUE_TYPE (a) == G_VALUE_TYPE (b));
  switch (G_VALUE_TYPE (a))
    {
      case G_TYPE_BOOLEAN:
        ret = (g_value_get_boolean (a) == g_value_get_boolean (b));
        break;
      case G_TYPE_UCHAR:
        ret = (g_value_get_uchar (a) == g_value_get_uchar (b));
        break;
      case G_TYPE_INT:
        ret = (g_value_get_int (a) == g_value_get_int (b));
        break;
      case G_TYPE_UINT:
        ret = (g_value_get_uint (a) == g_value_get_uint (b));
        break;
      case G_TYPE_INT64:
        ret = (g_value_get_int64 (a) == g_value_get_int64 (b));
        break;
      case G_TYPE_UINT64:
        ret = (g_value_get_uint64 (a) == g_value_get_uint64 (b));
        break;
      case G_TYPE_DOUBLE:
        {
          /* Avoid -Wfloat-equal warnings by doing a direct bit compare */
          gdouble da = g_value_get_double (a);
          gdouble db = g_value_get_double (b);
          ret = memcmp (&da, &db, sizeof (gdouble)) == 0;
        }
        break;
      case G_TYPE_STRING:
        ret = (g_strcmp0 (g_value_get_string (a), g_value_get_string (b)) == 0);
        break;
      case G_TYPE_VARIANT:
        ret = _g_variant_equal0 (g_value_get_variant (a), g_value_get_variant (b));
        break;
      default:
        if (G_VALUE_TYPE (a) == G_TYPE_STRV)
          ret = _g_strv_equal0 (g_value_get_boxed (a), g_value_get_boxed (b));
        else
          g_critical ("_g_value_equal() does not handle type %s", g_type_name (G_VALUE_TYPE (a)));
        break;
    }
  return ret;
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 2);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              data2);

  g_value_set_boolean (return_value, v_return);
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING_UINT_UINT (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectStringUintUintFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        const gchar *arg_type,
        guint arg_timespan,
        guint arg_resolution,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectStringUintUintFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 5);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectStringUintUintFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              g_marshal_value_peek_string (param_values + 2),
              g_marshal_value_peek_uint (param_values + 3),
              g_marshal_value_peek_uint (param_values + 4),
              data2);

  g_value_set_boolean (return_value, v_return);
}

static void
_g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint G_GNUC_UNUSED,
    void         *marshal_data)
{
  typedef gboolean (*_GDbusCodegenMarshalBoolean_ObjectStringFunc)
       (void *data1,
        GDBusMethodInvocation *arg_method_invocation,
        const gchar *arg_type,
        void *data2);
  _GDbusCodegenMarshalBoolean_ObjectStringFunc callback;
  GCClosure *cc = (GCClosure*) closure;
  void *data1, *data2;
  gboolean v_return;

  g_return_if_fail (return_value != NULL);
  g_return_if_fail (n_param_values == 3);

  if (G_CCLOSURE_SWAP_DATA (closure))
    {
      data1 = closure->data;
      data2 = g_value_peek_pointer (param_values + 0);
    }
  else
    {
      data1 = g_value_peek_pointer (param_values + 0);
      data2 = closure->data;
    }

  callback = (_GDbusCodegenMarshalBoolean_ObjectStringFunc)
    (marshal_data ? marshal_data : cc->callback);

  v_return =
    callback (data1,
              g_marshal_value_peek_object (param_values + 1),
              g_marshal_value_peek_string (param_values + 2),
              data2);

  g_value_set_boolean (return_value, v_return);
}

/* ------------------------------------------------------------------------
 * Code for interface org.freedesktop.UPower.Device
 * ------------------------------------------------------------------------
 */

/**
 * SECTION:GfUPowerDeviceGen
 * @title: GfUPowerDeviceGen
 * @short_description: Generated C code for the org.freedesktop.UPower.Device D-Bus interface
 *
 * This section contains code for working with the <link linkend="gdbus-interface-org-freedesktop-UPower-Device.top_of_page">org.freedesktop.UPower.Device</link> D-Bus interface in C.
 */

/* ---- Introspection data for org.freedesktop.UPower.Device ---- */

static const _ExtendedGDBusMethodInfo _gf_upower_device_gen_method_info_refresh =
{
  {
    -1,
    (gchar *) "Refresh",
    NULL,
    NULL,
    NULL
  },
  "handle-refresh",
  FALSE
};

static const _ExtendedGDBusArgInfo _gf_upower_device_gen_method_info_get_history_IN_ARG_type =
{
  {
    -1,
    (gchar *) "type",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gf_upower_device_gen_method_info_get_history_IN_ARG_timespan =
{
  {
    -1,
    (gchar *) "timespan",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const _ExtendedGDBusArgInfo _gf_upower_device_gen_method_info_get_history_IN_ARG_resolution =
{
  {
    -1,
    (gchar *) "resolution",
    (gchar *) "u",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const _gf_upower_device_gen_method_info_get_history_IN_ARG_pointers[] =
{
  &_gf_upower_device_gen_method_info_get_history_IN_ARG_type.parent_struct,
  &_gf_upower_device_gen_method_info_get_history_IN_ARG_timespan.parent_struct,
  &_gf_upower_device_gen_method_info_get_history_IN_ARG_resolution.parent_struct,
  NULL
};

static const _ExtendedGDBusArgInfo _gf_upower_device_gen_method_info_get_history_OUT_ARG_data =
{
  {
    -1,
    (gchar *) "data",
    (gchar *) "a(udu)",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const _gf_upower_device_gen_method_info_get_history_OUT_ARG_pointers[] =
{
  &_gf_upower_device_gen_method_info_get_history_OUT_ARG_data.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo _gf_upower_device_gen_method_info_get_history =
{
  {
    -1,
    (gchar *) "GetHistory",
    (GDBusArgInfo **) &_gf_upower_device_gen_method_info_get_history_IN_ARG_pointers,
    (GDBusArgInfo **) &_gf_upower_device_gen_method_info_get_history_OUT_ARG_pointers,
    NULL
  },
  "handle-get-history",
  FALSE
};

static const _ExtendedGDBusArgInfo _gf_upower_device_gen_method_info_get_statistics_IN_ARG_type =
{
  {
    -1,
    (gchar *) "type",
    (gchar *) "s",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const _gf_upower_device_gen_method_info_get_statistics_IN_ARG_pointers[] =
{
  &_gf_upower_device_gen_method_info_get_statistics_IN_ARG_type.parent_struct,
  NULL
};

static const _ExtendedGDBusArgInfo _gf_upower_device_gen_method_info_get_statistics_OUT_ARG_data =
{
  {
    -1,
    (gchar *) "data",
    (gchar *) "a(dd)",
    NULL
  },
  FALSE
};

static const GDBusArgInfo * const _gf_upower_device_gen_method_info_get_statistics_OUT_ARG_pointers[] =
{
  &_gf_upower_device_gen_method_info_get_statistics_OUT_ARG_data.parent_struct,
  NULL
};

static const _ExtendedGDBusMethodInfo _gf_upower_device_gen_method_info_get_statistics =
{
  {
    -1,
    (gchar *) "GetStatistics",
    (GDBusArgInfo **) &_gf_upower_device_gen_method_info_get_statistics_IN_ARG_pointers,
    (GDBusArgInfo **) &_gf_upower_device_gen_method_info_get_statistics_OUT_ARG_pointers,
    NULL
  },
  "handle-get-statistics",
  FALSE
};

static const GDBusMethodInfo * const _gf_upower_device_gen_method_info_pointers[] =
{
  &_gf_upower_device_gen_method_info_refresh.parent_struct,
  &_gf_upower_device_gen_method_info_get_history.parent_struct,
  &_gf_upower_device_gen_method_info_get_statistics.parent_struct,
  NULL
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_native_path =
{
  {
    -1,
    (gchar *) "NativePath",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "native-path",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_vendor =
{
  {
    -1,
    (gchar *) "Vendor",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "vendor",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_model =
{
  {
    -1,
    (gchar *) "Model",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "model",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_serial =
{
  {
    -1,
    (gchar *) "Serial",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "serial",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_update_time =
{
  {
    -1,
    (gchar *) "UpdateTime",
    (gchar *) "t",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "update-time",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_type_ =
{
  {
    -1,
    (gchar *) "Type",
    (gchar *) "u",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "type",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_power_supply =
{
  {
    -1,
    (gchar *) "PowerSupply",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "power-supply",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_has_history =
{
  {
    -1,
    (gchar *) "HasHistory",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "has-history",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_has_statistics =
{
  {
    -1,
    (gchar *) "HasStatistics",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "has-statistics",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_online =
{
  {
    -1,
    (gchar *) "Online",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "online",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_energy =
{
  {
    -1,
    (gchar *) "Energy",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "energy",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_energy_empty =
{
  {
    -1,
    (gchar *) "EnergyEmpty",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "energy-empty",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_energy_full =
{
  {
    -1,
    (gchar *) "EnergyFull",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "energy-full",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_energy_full_design =
{
  {
    -1,
    (gchar *) "EnergyFullDesign",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "energy-full-design",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_energy_rate =
{
  {
    -1,
    (gchar *) "EnergyRate",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "energy-rate",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_voltage =
{
  {
    -1,
    (gchar *) "Voltage",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "voltage",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_luminosity =
{
  {
    -1,
    (gchar *) "Luminosity",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "luminosity",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_time_to_empty =
{
  {
    -1,
    (gchar *) "TimeToEmpty",
    (gchar *) "x",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "time-to-empty",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_time_to_full =
{
  {
    -1,
    (gchar *) "TimeToFull",
    (gchar *) "x",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "time-to-full",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_percentage =
{
  {
    -1,
    (gchar *) "Percentage",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "percentage",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_temperature =
{
  {
    -1,
    (gchar *) "Temperature",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "temperature",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_is_present =
{
  {
    -1,
    (gchar *) "IsPresent",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "is-present",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_state =
{
  {
    -1,
    (gchar *) "State",
    (gchar *) "u",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "state",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_is_rechargeable =
{
  {
    -1,
    (gchar *) "IsRechargeable",
    (gchar *) "b",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "is-rechargeable",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_capacity =
{
  {
    -1,
    (gchar *) "Capacity",
    (gchar *) "d",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "capacity",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_technology =
{
  {
    -1,
    (gchar *) "Technology",
    (gchar *) "u",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "technology",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_warning_level =
{
  {
    -1,
    (gchar *) "WarningLevel",
    (gchar *) "u",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "warning-level",
  FALSE,
  TRUE
};

static const _ExtendedGDBusPropertyInfo _gf_upower_device_gen_property_info_icon_name =
{
  {
    -1,
    (gchar *) "IconName",
    (gchar *) "s",
    G_DBUS_PROPERTY_INFO_FLAGS_READABLE,
    NULL
  },
  "icon-name",
  FALSE,
  TRUE
};

static const GDBusPropertyInfo * const _gf_upower_device_gen_property_info_pointers[] =
{
  &_gf_upower_device_gen_property_info_native_path.parent_struct,
  &_gf_upower_device_gen_property_info_vendor.parent_struct,
  &_gf_upower_device_gen_property_info_model.parent_struct,
  &_gf_upower_device_gen_property_info_serial.parent_struct,
  &_gf_upower_device_gen_property_info_update_time.parent_struct,
  &_gf_upower_device_gen_property_info_type_.parent_struct,
  &_gf_upower_device_gen_property_info_power_supply.parent_struct,
  &_gf_upower_device_gen_property_info_has_history.parent_struct,
  &_gf_upower_device_gen_property_info_has_statistics.parent_struct,
  &_gf_upower_device_gen_property_info_online.parent_struct,
  &_gf_upower_device_gen_property_info_energy.parent_struct,
  &_gf_upower_device_gen_property_info_energy_empty.parent_struct,
  &_gf_upower_device_gen_property_info_energy_full.parent_struct,
  &_gf_upower_device_gen_property_info_energy_full_design.parent_struct,
  &_gf_upower_device_gen_property_info_energy_rate.parent_struct,
  &_gf_upower_device_gen_property_info_voltage.parent_struct,
  &_gf_upower_device_gen_property_info_luminosity.parent_struct,
  &_gf_upower_device_gen_property_info_time_to_empty.parent_struct,
  &_gf_upower_device_gen_property_info_time_to_full.parent_struct,
  &_gf_upower_device_gen_property_info_percentage.parent_struct,
  &_gf_upower_device_gen_property_info_temperature.parent_struct,
  &_gf_upower_device_gen_property_info_is_present.parent_struct,
  &_gf_upower_device_gen_property_info_state.parent_struct,
  &_gf_upower_device_gen_property_info_is_rechargeable.parent_struct,
  &_gf_upower_device_gen_property_info_capacity.parent_struct,
  &_gf_upower_device_gen_property_info_technology.parent_struct,
  &_gf_upower_device_gen_property_info_warning_level.parent_struct,
  &_gf_upower_device_gen_property_info_icon_name.parent_struct,
  NULL
};

static const _ExtendedGDBusInterfaceInfo _gf_upower_device_gen_interface_info =
{
  {
    -1,
    (gchar *) "org.freedesktop.UPower.Device",
    (GDBusMethodInfo **) &_gf_upower_device_gen_method_info_pointers,
    NULL,
    (GDBusPropertyInfo **) &_gf_upower_device_gen_property_info_pointers,
    NULL
  },
  "upower-device-gen",
};


/**
 * gf_upower_device_gen_interface_info:
 *
 * Gets a machine-readable description of the <link linkend="gdbus-interface-org-freedesktop-UPower-Device.top_of_page">org.freedesktop.UPower.Device</link> D-Bus interface.
 *
 * Returns: (transfer none): A #GDBusInterfaceInfo. Do not free.
 */
GDBusInterfaceInfo *
gf_upower_device_gen_interface_info (void)
{
  return (GDBusInterfaceInfo *) &_gf_upower_device_gen_interface_info.parent_struct;
}

/**
 * gf_upower_device_gen_override_properties:
 * @klass: The class structure for a #GObject derived class.
 * @property_id_begin: The property id to assign to the first overridden property.
 *
 * Overrides all #GObject properties in the #GfUPowerDeviceGen interface for a concrete class.
 * The properties are overridden in the order they are defined.
 *
 * Returns: The last property id.
 */
guint
gf_upower_device_gen_override_properties (GObjectClass *klass, guint property_id_begin)
{
  g_object_class_override_property (klass, property_id_begin++, "native-path");
  g_object_class_override_property (klass, property_id_begin++, "vendor");
  g_object_class_override_property (klass, property_id_begin++, "model");
  g_object_class_override_property (klass, property_id_begin++, "serial");
  g_object_class_override_property (klass, property_id_begin++, "update-time");
  g_object_class_override_property (klass, property_id_begin++, "type");
  g_object_class_override_property (klass, property_id_begin++, "power-supply");
  g_object_class_override_property (klass, property_id_begin++, "has-history");
  g_object_class_override_property (klass, property_id_begin++, "has-statistics");
  g_object_class_override_property (klass, property_id_begin++, "online");
  g_object_class_override_property (klass, property_id_begin++, "energy");
  g_object_class_override_property (klass, property_id_begin++, "energy-empty");
  g_object_class_override_property (klass, property_id_begin++, "energy-full");
  g_object_class_override_property (klass, property_id_begin++, "energy-full-design");
  g_object_class_override_property (klass, property_id_begin++, "energy-rate");
  g_object_class_override_property (klass, property_id_begin++, "voltage");
  g_object_class_override_property (klass, property_id_begin++, "luminosity");
  g_object_class_override_property (klass, property_id_begin++, "time-to-empty");
  g_object_class_override_property (klass, property_id_begin++, "time-to-full");
  g_object_class_override_property (klass, property_id_begin++, "percentage");
  g_object_class_override_property (klass, property_id_begin++, "temperature");
  g_object_class_override_property (klass, property_id_begin++, "is-present");
  g_object_class_override_property (klass, property_id_begin++, "state");
  g_object_class_override_property (klass, property_id_begin++, "is-rechargeable");
  g_object_class_override_property (klass, property_id_begin++, "capacity");
  g_object_class_override_property (klass, property_id_begin++, "technology");
  g_object_class_override_property (klass, property_id_begin++, "warning-level");
  g_object_class_override_property (klass, property_id_begin++, "icon-name");
  return property_id_begin - 1;
}


inline static void
gf_upower_device_gen_method_marshal_refresh (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
gf_upower_device_gen_method_marshal_get_history (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING_UINT_UINT (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}

inline static void
gf_upower_device_gen_method_marshal_get_statistics (
    GClosure     *closure,
    GValue       *return_value,
    unsigned int  n_param_values,
    const GValue *param_values,
    void         *invocation_hint,
    void         *marshal_data)
{
  _g_dbus_codegen_marshal_BOOLEAN__OBJECT_STRING (closure,
    return_value, n_param_values, param_values, invocation_hint, marshal_data);
}


/**
 * GfUPowerDeviceGen:
 *
 * Abstract interface type for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-UPower-Device.top_of_page">org.freedesktop.UPower.Device</link>.
 */

/**
 * GfUPowerDeviceGenIface:
 * @parent_iface: The parent interface.
 * @handle_get_history: Handler for the #GfUPowerDeviceGen::handle-get-history signal.
 * @handle_get_statistics: Handler for the #GfUPowerDeviceGen::handle-get-statistics signal.
 * @handle_refresh: Handler for the #GfUPowerDeviceGen::handle-refresh signal.
 * @get_capacity: Getter for the #GfUPowerDeviceGen:capacity property.
 * @get_energy: Getter for the #GfUPowerDeviceGen:energy property.
 * @get_energy_empty: Getter for the #GfUPowerDeviceGen:energy-empty property.
 * @get_energy_full: Getter for the #GfUPowerDeviceGen:energy-full property.
 * @get_energy_full_design: Getter for the #GfUPowerDeviceGen:energy-full-design property.
 * @get_energy_rate: Getter for the #GfUPowerDeviceGen:energy-rate property.
 * @get_has_history: Getter for the #GfUPowerDeviceGen:has-history property.
 * @get_has_statistics: Getter for the #GfUPowerDeviceGen:has-statistics property.
 * @get_icon_name: Getter for the #GfUPowerDeviceGen:icon-name property.
 * @get_is_present: Getter for the #GfUPowerDeviceGen:is-present property.
 * @get_is_rechargeable: Getter for the #GfUPowerDeviceGen:is-rechargeable property.
 * @get_luminosity: Getter for the #GfUPowerDeviceGen:luminosity property.
 * @get_model: Getter for the #GfUPowerDeviceGen:model property.
 * @get_native_path: Getter for the #GfUPowerDeviceGen:native-path property.
 * @get_online: Getter for the #GfUPowerDeviceGen:online property.
 * @get_percentage: Getter for the #GfUPowerDeviceGen:percentage property.
 * @get_power_supply: Getter for the #GfUPowerDeviceGen:power-supply property.
 * @get_serial: Getter for the #GfUPowerDeviceGen:serial property.
 * @get_state: Getter for the #GfUPowerDeviceGen:state property.
 * @get_technology: Getter for the #GfUPowerDeviceGen:technology property.
 * @get_temperature: Getter for the #GfUPowerDeviceGen:temperature property.
 * @get_time_to_empty: Getter for the #GfUPowerDeviceGen:time-to-empty property.
 * @get_time_to_full: Getter for the #GfUPowerDeviceGen:time-to-full property.
 * @get_type_: Getter for the #GfUPowerDeviceGen:type property.
 * @get_update_time: Getter for the #GfUPowerDeviceGen:update-time property.
 * @get_vendor: Getter for the #GfUPowerDeviceGen:vendor property.
 * @get_voltage: Getter for the #GfUPowerDeviceGen:voltage property.
 * @get_warning_level: Getter for the #GfUPowerDeviceGen:warning-level property.
 *
 * Virtual table for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-UPower-Device.top_of_page">org.freedesktop.UPower.Device</link>.
 */

typedef GfUPowerDeviceGenIface GfUPowerDeviceGenInterface;
G_DEFINE_INTERFACE (GfUPowerDeviceGen, gf_upower_device_gen, G_TYPE_OBJECT)

static void
gf_upower_device_gen_default_init (GfUPowerDeviceGenIface *iface)
{
  /* GObject signals for incoming D-Bus method calls: */
  /**
   * GfUPowerDeviceGen::handle-refresh:
   * @object: A #GfUPowerDeviceGen.
   * @invocation: A #GDBusMethodInvocation.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-UPower-Device.Refresh">Refresh()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gf_upower_device_gen_complete_refresh() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-refresh",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GfUPowerDeviceGenIface, handle_refresh),
    g_signal_accumulator_true_handled,
    NULL,
      gf_upower_device_gen_method_marshal_refresh,
    G_TYPE_BOOLEAN,
    1,
    G_TYPE_DBUS_METHOD_INVOCATION);

  /**
   * GfUPowerDeviceGen::handle-get-history:
   * @object: A #GfUPowerDeviceGen.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_type: Argument passed by remote caller.
   * @arg_timespan: Argument passed by remote caller.
   * @arg_resolution: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-UPower-Device.GetHistory">GetHistory()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gf_upower_device_gen_complete_get_history() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-get-history",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GfUPowerDeviceGenIface, handle_get_history),
    g_signal_accumulator_true_handled,
    NULL,
      gf_upower_device_gen_method_marshal_get_history,
    G_TYPE_BOOLEAN,
    4,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_UINT);

  /**
   * GfUPowerDeviceGen::handle-get-statistics:
   * @object: A #GfUPowerDeviceGen.
   * @invocation: A #GDBusMethodInvocation.
   * @arg_type: Argument passed by remote caller.
   *
   * Signal emitted when a remote caller is invoking the <link linkend="gdbus-method-org-freedesktop-UPower-Device.GetStatistics">GetStatistics()</link> D-Bus method.
   *
   * If a signal handler returns %TRUE, it means the signal handler will handle the invocation (e.g. take a reference to @invocation and eventually call gf_upower_device_gen_complete_get_statistics() or e.g. g_dbus_method_invocation_return_error() on it) and no other signal handlers will run. If no signal handler handles the invocation, the %G_DBUS_ERROR_UNKNOWN_METHOD error is returned.
   *
   * Returns: %G_DBUS_METHOD_INVOCATION_HANDLED or %TRUE if the invocation was handled, %G_DBUS_METHOD_INVOCATION_UNHANDLED or %FALSE to let other signal handlers run.
   */
  g_signal_new ("handle-get-statistics",
    G_TYPE_FROM_INTERFACE (iface),
    G_SIGNAL_RUN_LAST,
    G_STRUCT_OFFSET (GfUPowerDeviceGenIface, handle_get_statistics),
    g_signal_accumulator_true_handled,
    NULL,
      gf_upower_device_gen_method_marshal_get_statistics,
    G_TYPE_BOOLEAN,
    2,
    G_TYPE_DBUS_METHOD_INVOCATION, G_TYPE_STRING);

  /* GObject properties for D-Bus properties: */
  /**
   * GfUPowerDeviceGen:native-path:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.NativePath">"NativePath"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("native-path", "NativePath", "NativePath", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:vendor:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Vendor">"Vendor"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("vendor", "Vendor", "Vendor", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:model:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Model">"Model"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("model", "Model", "Model", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:serial:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Serial">"Serial"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("serial", "Serial", "Serial", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:update-time:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.UpdateTime">"UpdateTime"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint64 ("update-time", "UpdateTime", "UpdateTime", 0, G_MAXUINT64, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:type:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Type">"Type"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint ("type", "Type", "Type", 0, G_MAXUINT32, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:power-supply:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.PowerSupply">"PowerSupply"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("power-supply", "PowerSupply", "PowerSupply", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:has-history:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.HasHistory">"HasHistory"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("has-history", "HasHistory", "HasHistory", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:has-statistics:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.HasStatistics">"HasStatistics"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("has-statistics", "HasStatistics", "HasStatistics", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:online:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Online">"Online"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("online", "Online", "Online", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:energy:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Energy">"Energy"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("energy", "Energy", "Energy", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:energy-empty:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyEmpty">"EnergyEmpty"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("energy-empty", "EnergyEmpty", "EnergyEmpty", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:energy-full:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyFull">"EnergyFull"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("energy-full", "EnergyFull", "EnergyFull", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:energy-full-design:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyFullDesign">"EnergyFullDesign"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("energy-full-design", "EnergyFullDesign", "EnergyFullDesign", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:energy-rate:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyRate">"EnergyRate"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("energy-rate", "EnergyRate", "EnergyRate", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:voltage:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Voltage">"Voltage"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("voltage", "Voltage", "Voltage", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:luminosity:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Luminosity">"Luminosity"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("luminosity", "Luminosity", "Luminosity", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:time-to-empty:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.TimeToEmpty">"TimeToEmpty"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_int64 ("time-to-empty", "TimeToEmpty", "TimeToEmpty", G_MININT64, G_MAXINT64, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:time-to-full:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.TimeToFull">"TimeToFull"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_int64 ("time-to-full", "TimeToFull", "TimeToFull", G_MININT64, G_MAXINT64, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:percentage:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Percentage">"Percentage"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("percentage", "Percentage", "Percentage", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:temperature:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Temperature">"Temperature"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("temperature", "Temperature", "Temperature", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:is-present:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.IsPresent">"IsPresent"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("is-present", "IsPresent", "IsPresent", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:state:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.State">"State"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint ("state", "State", "State", 0, G_MAXUINT32, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:is-rechargeable:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.IsRechargeable">"IsRechargeable"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_boolean ("is-rechargeable", "IsRechargeable", "IsRechargeable", FALSE, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:capacity:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Capacity">"Capacity"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_double ("capacity", "Capacity", "Capacity", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:technology:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.Technology">"Technology"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint ("technology", "Technology", "Technology", 0, G_MAXUINT32, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:warning-level:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.WarningLevel">"WarningLevel"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_uint ("warning-level", "WarningLevel", "WarningLevel", 0, G_MAXUINT32, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
  /**
   * GfUPowerDeviceGen:icon-name:
   *
   * Represents the D-Bus property <link linkend="gdbus-property-org-freedesktop-UPower-Device.IconName">"IconName"</link>.
   *
   * Since the D-Bus property for this #GObject property is readable but not writable, it is meaningful to read from it on both the client- and service-side. It is only meaningful, however, to write to it on the service-side.
   */
  g_object_interface_install_property (iface,
    g_param_spec_string ("icon-name", "IconName", "IconName", NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
}

/**
 * gf_upower_device_gen_get_native_path: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.NativePath">"NativePath"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use gf_upower_device_gen_dup_native_path() if on another thread.
 *
 * Returns: (transfer none) (nullable): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
gf_upower_device_gen_get_native_path (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), NULL);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_native_path (object);
}

/**
 * gf_upower_device_gen_dup_native_path: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.NativePath">"NativePath"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full) (nullable): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
gf_upower_device_gen_dup_native_path (GfUPowerDeviceGen *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "native-path", &value, NULL);
  return value;
}

/**
 * gf_upower_device_gen_set_native_path: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.NativePath">"NativePath"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_native_path (GfUPowerDeviceGen *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "native-path", value, NULL);
}

/**
 * gf_upower_device_gen_get_vendor: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Vendor">"Vendor"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use gf_upower_device_gen_dup_vendor() if on another thread.
 *
 * Returns: (transfer none) (nullable): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
gf_upower_device_gen_get_vendor (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), NULL);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_vendor (object);
}

/**
 * gf_upower_device_gen_dup_vendor: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Vendor">"Vendor"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full) (nullable): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
gf_upower_device_gen_dup_vendor (GfUPowerDeviceGen *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "vendor", &value, NULL);
  return value;
}

/**
 * gf_upower_device_gen_set_vendor: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Vendor">"Vendor"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_vendor (GfUPowerDeviceGen *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "vendor", value, NULL);
}

/**
 * gf_upower_device_gen_get_model: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Model">"Model"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use gf_upower_device_gen_dup_model() if on another thread.
 *
 * Returns: (transfer none) (nullable): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
gf_upower_device_gen_get_model (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), NULL);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_model (object);
}

/**
 * gf_upower_device_gen_dup_model: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Model">"Model"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full) (nullable): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
gf_upower_device_gen_dup_model (GfUPowerDeviceGen *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "model", &value, NULL);
  return value;
}

/**
 * gf_upower_device_gen_set_model: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Model">"Model"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_model (GfUPowerDeviceGen *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "model", value, NULL);
}

/**
 * gf_upower_device_gen_get_serial: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Serial">"Serial"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use gf_upower_device_gen_dup_serial() if on another thread.
 *
 * Returns: (transfer none) (nullable): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
gf_upower_device_gen_get_serial (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), NULL);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_serial (object);
}

/**
 * gf_upower_device_gen_dup_serial: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Serial">"Serial"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full) (nullable): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
gf_upower_device_gen_dup_serial (GfUPowerDeviceGen *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "serial", &value, NULL);
  return value;
}

/**
 * gf_upower_device_gen_set_serial: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Serial">"Serial"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_serial (GfUPowerDeviceGen *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "serial", value, NULL);
}

/**
 * gf_upower_device_gen_get_update_time: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.UpdateTime">"UpdateTime"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint64 
gf_upower_device_gen_get_update_time (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_update_time (object);
}

/**
 * gf_upower_device_gen_set_update_time: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.UpdateTime">"UpdateTime"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_update_time (GfUPowerDeviceGen *object, guint64 value)
{
  g_object_set (G_OBJECT (object), "update-time", value, NULL);
}

/**
 * gf_upower_device_gen_get_type_: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Type">"Type"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint 
gf_upower_device_gen_get_type_ (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_type_ (object);
}

/**
 * gf_upower_device_gen_set_type_: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Type">"Type"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_type_ (GfUPowerDeviceGen *object, guint value)
{
  g_object_set (G_OBJECT (object), "type", value, NULL);
}

/**
 * gf_upower_device_gen_get_power_supply: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.PowerSupply">"PowerSupply"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
gf_upower_device_gen_get_power_supply (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), FALSE);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_power_supply (object);
}

/**
 * gf_upower_device_gen_set_power_supply: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.PowerSupply">"PowerSupply"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_power_supply (GfUPowerDeviceGen *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "power-supply", value, NULL);
}

/**
 * gf_upower_device_gen_get_has_history: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.HasHistory">"HasHistory"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
gf_upower_device_gen_get_has_history (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), FALSE);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_has_history (object);
}

/**
 * gf_upower_device_gen_set_has_history: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.HasHistory">"HasHistory"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_has_history (GfUPowerDeviceGen *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "has-history", value, NULL);
}

/**
 * gf_upower_device_gen_get_has_statistics: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.HasStatistics">"HasStatistics"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
gf_upower_device_gen_get_has_statistics (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), FALSE);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_has_statistics (object);
}

/**
 * gf_upower_device_gen_set_has_statistics: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.HasStatistics">"HasStatistics"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_has_statistics (GfUPowerDeviceGen *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "has-statistics", value, NULL);
}

/**
 * gf_upower_device_gen_get_online: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Online">"Online"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
gf_upower_device_gen_get_online (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), FALSE);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_online (object);
}

/**
 * gf_upower_device_gen_set_online: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Online">"Online"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_online (GfUPowerDeviceGen *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "online", value, NULL);
}

/**
 * gf_upower_device_gen_get_energy: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Energy">"Energy"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_energy (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_energy (object);
}

/**
 * gf_upower_device_gen_set_energy: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Energy">"Energy"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_energy (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "energy", value, NULL);
}

/**
 * gf_upower_device_gen_get_energy_empty: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyEmpty">"EnergyEmpty"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_energy_empty (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_energy_empty (object);
}

/**
 * gf_upower_device_gen_set_energy_empty: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyEmpty">"EnergyEmpty"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_energy_empty (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "energy-empty", value, NULL);
}

/**
 * gf_upower_device_gen_get_energy_full: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyFull">"EnergyFull"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_energy_full (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_energy_full (object);
}

/**
 * gf_upower_device_gen_set_energy_full: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyFull">"EnergyFull"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_energy_full (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "energy-full", value, NULL);
}

/**
 * gf_upower_device_gen_get_energy_full_design: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyFullDesign">"EnergyFullDesign"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_energy_full_design (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_energy_full_design (object);
}

/**
 * gf_upower_device_gen_set_energy_full_design: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyFullDesign">"EnergyFullDesign"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_energy_full_design (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "energy-full-design", value, NULL);
}

/**
 * gf_upower_device_gen_get_energy_rate: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyRate">"EnergyRate"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_energy_rate (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_energy_rate (object);
}

/**
 * gf_upower_device_gen_set_energy_rate: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.EnergyRate">"EnergyRate"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_energy_rate (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "energy-rate", value, NULL);
}

/**
 * gf_upower_device_gen_get_voltage: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Voltage">"Voltage"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_voltage (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_voltage (object);
}

/**
 * gf_upower_device_gen_set_voltage: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Voltage">"Voltage"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_voltage (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "voltage", value, NULL);
}

/**
 * gf_upower_device_gen_get_luminosity: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Luminosity">"Luminosity"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_luminosity (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_luminosity (object);
}

/**
 * gf_upower_device_gen_set_luminosity: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Luminosity">"Luminosity"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_luminosity (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "luminosity", value, NULL);
}

/**
 * gf_upower_device_gen_get_time_to_empty: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.TimeToEmpty">"TimeToEmpty"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gint64 
gf_upower_device_gen_get_time_to_empty (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_time_to_empty (object);
}

/**
 * gf_upower_device_gen_set_time_to_empty: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.TimeToEmpty">"TimeToEmpty"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_time_to_empty (GfUPowerDeviceGen *object, gint64 value)
{
  g_object_set (G_OBJECT (object), "time-to-empty", value, NULL);
}

/**
 * gf_upower_device_gen_get_time_to_full: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.TimeToFull">"TimeToFull"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gint64 
gf_upower_device_gen_get_time_to_full (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_time_to_full (object);
}

/**
 * gf_upower_device_gen_set_time_to_full: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.TimeToFull">"TimeToFull"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_time_to_full (GfUPowerDeviceGen *object, gint64 value)
{
  g_object_set (G_OBJECT (object), "time-to-full", value, NULL);
}

/**
 * gf_upower_device_gen_get_percentage: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Percentage">"Percentage"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_percentage (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_percentage (object);
}

/**
 * gf_upower_device_gen_set_percentage: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Percentage">"Percentage"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_percentage (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "percentage", value, NULL);
}

/**
 * gf_upower_device_gen_get_temperature: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Temperature">"Temperature"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_temperature (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_temperature (object);
}

/**
 * gf_upower_device_gen_set_temperature: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Temperature">"Temperature"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_temperature (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "temperature", value, NULL);
}

/**
 * gf_upower_device_gen_get_is_present: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.IsPresent">"IsPresent"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
gf_upower_device_gen_get_is_present (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), FALSE);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_is_present (object);
}

/**
 * gf_upower_device_gen_set_is_present: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.IsPresent">"IsPresent"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_is_present (GfUPowerDeviceGen *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "is-present", value, NULL);
}

/**
 * gf_upower_device_gen_get_state: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.State">"State"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint 
gf_upower_device_gen_get_state (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_state (object);
}

/**
 * gf_upower_device_gen_set_state: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.State">"State"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_state (GfUPowerDeviceGen *object, guint value)
{
  g_object_set (G_OBJECT (object), "state", value, NULL);
}

/**
 * gf_upower_device_gen_get_is_rechargeable: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.IsRechargeable">"IsRechargeable"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gboolean 
gf_upower_device_gen_get_is_rechargeable (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), FALSE);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_is_rechargeable (object);
}

/**
 * gf_upower_device_gen_set_is_rechargeable: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.IsRechargeable">"IsRechargeable"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_is_rechargeable (GfUPowerDeviceGen *object, gboolean value)
{
  g_object_set (G_OBJECT (object), "is-rechargeable", value, NULL);
}

/**
 * gf_upower_device_gen_get_capacity: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Capacity">"Capacity"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
gdouble 
gf_upower_device_gen_get_capacity (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0.0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_capacity (object);
}

/**
 * gf_upower_device_gen_set_capacity: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Capacity">"Capacity"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_capacity (GfUPowerDeviceGen *object, gdouble value)
{
  g_object_set (G_OBJECT (object), "capacity", value, NULL);
}

/**
 * gf_upower_device_gen_get_technology: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Technology">"Technology"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint 
gf_upower_device_gen_get_technology (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_technology (object);
}

/**
 * gf_upower_device_gen_set_technology: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.Technology">"Technology"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_technology (GfUPowerDeviceGen *object, guint value)
{
  g_object_set (G_OBJECT (object), "technology", value, NULL);
}

/**
 * gf_upower_device_gen_get_warning_level: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.WarningLevel">"WarningLevel"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: The property value.
 */
guint 
gf_upower_device_gen_get_warning_level (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), 0);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_warning_level (object);
}

/**
 * gf_upower_device_gen_set_warning_level: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.WarningLevel">"WarningLevel"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_warning_level (GfUPowerDeviceGen *object, guint value)
{
  g_object_set (G_OBJECT (object), "warning-level", value, NULL);
}

/**
 * gf_upower_device_gen_get_icon_name: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets the value of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.IconName">"IconName"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * The returned value is only valid until the property changes so on the client-side it is only safe to use this function on the thread where @object was constructed. Use gf_upower_device_gen_dup_icon_name() if on another thread.
 *
 * Returns: (transfer none) (nullable): The property value or %NULL if the property is not set. Do not free the returned value, it belongs to @object.
 */
const gchar *
gf_upower_device_gen_get_icon_name (GfUPowerDeviceGen *object)
{
  g_return_val_if_fail (GF_IS_UPOWER_DEVICE_GEN (object), NULL);

  return GF_UPOWER_DEVICE_GEN_GET_IFACE (object)->get_icon_name (object);
}

/**
 * gf_upower_device_gen_dup_icon_name: (skip)
 * @object: A #GfUPowerDeviceGen.
 *
 * Gets a copy of the <link linkend="gdbus-property-org-freedesktop-UPower-Device.IconName">"IconName"</link> D-Bus property.
 *
 * Since this D-Bus property is readable, it is meaningful to use this function on both the client- and service-side.
 *
 * Returns: (transfer full) (nullable): The property value or %NULL if the property is not set. The returned value should be freed with g_free().
 */
gchar *
gf_upower_device_gen_dup_icon_name (GfUPowerDeviceGen *object)
{
  gchar *value;
  g_object_get (G_OBJECT (object), "icon-name", &value, NULL);
  return value;
}

/**
 * gf_upower_device_gen_set_icon_name: (skip)
 * @object: A #GfUPowerDeviceGen.
 * @value: The value to set.
 *
 * Sets the <link linkend="gdbus-property-org-freedesktop-UPower-Device.IconName">"IconName"</link> D-Bus property to @value.
 *
 * Since this D-Bus property is not writable, it is only meaningful to use this function on the service-side.
 */
void
gf_upower_device_gen_set_icon_name (GfUPowerDeviceGen *object, const gchar *value)
{
  g_object_set (G_OBJECT (object), "icon-name", value, NULL);
}

/**
 * gf_upower_device_gen_call_refresh:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-UPower-Device.Refresh">Refresh()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call gf_upower_device_gen_call_refresh_finish() to get the result of the operation.
 *
 * See gf_upower_device_gen_call_refresh_sync() for the synchronous, blocking version of this method.
 */
void
gf_upower_device_gen_call_refresh (
    GfUPowerDeviceGen *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "Refresh",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gf_upower_device_gen_call_refresh_finish:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gf_upower_device_gen_call_refresh().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gf_upower_device_gen_call_refresh().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
gf_upower_device_gen_call_refresh_finish (
    GfUPowerDeviceGen *proxy,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gf_upower_device_gen_call_refresh_sync:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-UPower-Device.Refresh">Refresh()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gf_upower_device_gen_call_refresh() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
gf_upower_device_gen_call_refresh_sync (
    GfUPowerDeviceGen *proxy,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "Refresh",
    g_variant_new ("()"),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "()");
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gf_upower_device_gen_call_get_history:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @arg_type: Argument to pass with the method invocation.
 * @arg_timespan: Argument to pass with the method invocation.
 * @arg_resolution: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-UPower-Device.GetHistory">GetHistory()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call gf_upower_device_gen_call_get_history_finish() to get the result of the operation.
 *
 * See gf_upower_device_gen_call_get_history_sync() for the synchronous, blocking version of this method.
 */
void
gf_upower_device_gen_call_get_history (
    GfUPowerDeviceGen *proxy,
    const gchar *arg_type,
    guint arg_timespan,
    guint arg_resolution,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "GetHistory",
    g_variant_new ("(suu)",
                   arg_type,
                   arg_timespan,
                   arg_resolution),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gf_upower_device_gen_call_get_history_finish:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @out_data: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gf_upower_device_gen_call_get_history().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gf_upower_device_gen_call_get_history().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
gf_upower_device_gen_call_get_history_finish (
    GfUPowerDeviceGen *proxy,
    GVariant **out_data,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@a(udu))",
                 out_data);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gf_upower_device_gen_call_get_history_sync:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @arg_type: Argument to pass with the method invocation.
 * @arg_timespan: Argument to pass with the method invocation.
 * @arg_resolution: Argument to pass with the method invocation.
 * @out_data: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-UPower-Device.GetHistory">GetHistory()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gf_upower_device_gen_call_get_history() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
gf_upower_device_gen_call_get_history_sync (
    GfUPowerDeviceGen *proxy,
    const gchar *arg_type,
    guint arg_timespan,
    guint arg_resolution,
    GVariant **out_data,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "GetHistory",
    g_variant_new ("(suu)",
                   arg_type,
                   arg_timespan,
                   arg_resolution),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@a(udu))",
                 out_data);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gf_upower_device_gen_call_get_statistics:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @arg_type: Argument to pass with the method invocation.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied or %NULL.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously invokes the <link linkend="gdbus-method-org-freedesktop-UPower-Device.GetStatistics">GetStatistics()</link> D-Bus method on @proxy.
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call gf_upower_device_gen_call_get_statistics_finish() to get the result of the operation.
 *
 * See gf_upower_device_gen_call_get_statistics_sync() for the synchronous, blocking version of this method.
 */
void
gf_upower_device_gen_call_get_statistics (
    GfUPowerDeviceGen *proxy,
    const gchar *arg_type,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data)
{
  g_dbus_proxy_call (G_DBUS_PROXY (proxy),
    "GetStatistics",
    g_variant_new ("(s)",
                   arg_type),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    callback,
    user_data);
}

/**
 * gf_upower_device_gen_call_get_statistics_finish:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @out_data: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gf_upower_device_gen_call_get_statistics().
 * @error: Return location for error or %NULL.
 *
 * Finishes an operation started with gf_upower_device_gen_call_get_statistics().
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
gf_upower_device_gen_call_get_statistics_finish (
    GfUPowerDeviceGen *proxy,
    GVariant **out_data,
    GAsyncResult *res,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_finish (G_DBUS_PROXY (proxy), res, error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@a(dd))",
                 out_data);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gf_upower_device_gen_call_get_statistics_sync:
 * @proxy: A #GfUPowerDeviceGenProxy.
 * @arg_type: Argument to pass with the method invocation.
 * @out_data: (out) (optional): Return location for return parameter or %NULL to ignore.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL.
 *
 * Synchronously invokes the <link linkend="gdbus-method-org-freedesktop-UPower-Device.GetStatistics">GetStatistics()</link> D-Bus method on @proxy. The calling thread is blocked until a reply is received.
 *
 * See gf_upower_device_gen_call_get_statistics() for the asynchronous version of this method.
 *
 * Returns: (skip): %TRUE if the call succeeded, %FALSE if @error is set.
 */
gboolean
gf_upower_device_gen_call_get_statistics_sync (
    GfUPowerDeviceGen *proxy,
    const gchar *arg_type,
    GVariant **out_data,
    GCancellable *cancellable,
    GError **error)
{
  GVariant *_ret;
  _ret = g_dbus_proxy_call_sync (G_DBUS_PROXY (proxy),
    "GetStatistics",
    g_variant_new ("(s)",
                   arg_type),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    cancellable,
    error);
  if (_ret == NULL)
    goto _out;
  g_variant_get (_ret,
                 "(@a(dd))",
                 out_data);
  g_variant_unref (_ret);
_out:
  return _ret != NULL;
}

/**
 * gf_upower_device_gen_complete_refresh:
 * @object: A #GfUPowerDeviceGen.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-UPower-Device.Refresh">Refresh()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gf_upower_device_gen_complete_refresh (
    GfUPowerDeviceGen *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("()"));
}

/**
 * gf_upower_device_gen_complete_get_history:
 * @object: A #GfUPowerDeviceGen.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @data: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-UPower-Device.GetHistory">GetHistory()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gf_upower_device_gen_complete_get_history (
    GfUPowerDeviceGen *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    GVariant *data)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(@a(udu))",
                   data));
}

/**
 * gf_upower_device_gen_complete_get_statistics:
 * @object: A #GfUPowerDeviceGen.
 * @invocation: (transfer full): A #GDBusMethodInvocation.
 * @data: Parameter to return.
 *
 * Helper function used in service implementations to finish handling invocations of the <link linkend="gdbus-method-org-freedesktop-UPower-Device.GetStatistics">GetStatistics()</link> D-Bus method. If you instead want to finish handling an invocation by returning an error, use g_dbus_method_invocation_return_error() or similar.
 *
 * This method will free @invocation, you cannot use it afterwards.
 */
void
gf_upower_device_gen_complete_get_statistics (
    GfUPowerDeviceGen *object G_GNUC_UNUSED,
    GDBusMethodInvocation *invocation,
    GVariant *data)
{
  g_dbus_method_invocation_return_value (invocation,
    g_variant_new ("(@a(dd))",
                   data));
}

/* ------------------------------------------------------------------------ */

/**
 * GfUPowerDeviceGenProxy:
 *
 * The #GfUPowerDeviceGenProxy structure contains only private data and should only be accessed using the provided API.
 */

/**
 * GfUPowerDeviceGenProxyClass:
 * @parent_class: The parent class.
 *
 * Class structure for #GfUPowerDeviceGenProxy.
 */

struct _GfUPowerDeviceGenProxyPrivate
{
  GData *qdata;
};

static void gf_upower_device_gen_proxy_iface_init (GfUPowerDeviceGenIface *iface);

#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (GfUPowerDeviceGenProxy, gf_upower_device_gen_proxy, G_TYPE_DBUS_PROXY,
                         G_ADD_PRIVATE (GfUPowerDeviceGenProxy)
                         G_IMPLEMENT_INTERFACE (GF_TYPE_UPOWER_DEVICE_GEN, gf_upower_device_gen_proxy_iface_init))

#else
G_DEFINE_TYPE_WITH_CODE (GfUPowerDeviceGenProxy, gf_upower_device_gen_proxy, G_TYPE_DBUS_PROXY,
                         G_IMPLEMENT_INTERFACE (GF_TYPE_UPOWER_DEVICE_GEN, gf_upower_device_gen_proxy_iface_init))

#endif
static void
gf_upower_device_gen_proxy_finalize (GObject *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  g_datalist_clear (&proxy->priv->qdata);
  G_OBJECT_CLASS (gf_upower_device_gen_proxy_parent_class)->finalize (object);
}

static void
gf_upower_device_gen_proxy_get_property (GObject      *object,
  guint         prop_id,
  GValue       *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  const _ExtendedGDBusPropertyInfo *info;
  GVariant *variant;
  g_assert (prop_id != 0 && prop_id - 1 < 28);
  info = (const _ExtendedGDBusPropertyInfo *) _gf_upower_device_gen_property_info_pointers[prop_id - 1];
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (object), info->parent_struct.name);
  if (info->use_gvariant)
    {
      g_value_set_variant (value, variant);
    }
  else
    {
      if (variant != NULL)
        g_dbus_gvariant_to_gvalue (variant, value);
    }
  if (variant != NULL)
    g_variant_unref (variant);
}

static void
gf_upower_device_gen_proxy_set_property_cb (GDBusProxy *proxy,
  GAsyncResult *res,
  gpointer      user_data)
{
  const _ExtendedGDBusPropertyInfo *info = user_data;
  GError *error;
  GVariant *_ret;
  error = NULL;
  _ret = g_dbus_proxy_call_finish (proxy, res, &error);
  if (!_ret)
    {
      g_warning ("Error setting property '%s' on interface org.freedesktop.UPower.Device: %s (%s, %d)",
                 info->parent_struct.name, 
                 error->message, g_quark_to_string (error->domain), error->code);
      g_error_free (error);
    }
  else
    {
      g_variant_unref (_ret);
    }
}

static void
gf_upower_device_gen_proxy_set_property (GObject      *object,
  guint         prop_id,
  const GValue *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  const _ExtendedGDBusPropertyInfo *info;
  GVariant *variant;
  g_assert (prop_id != 0 && prop_id - 1 < 28);
  info = (const _ExtendedGDBusPropertyInfo *) _gf_upower_device_gen_property_info_pointers[prop_id - 1];
  variant = g_dbus_gvalue_to_gvariant (value, G_VARIANT_TYPE (info->parent_struct.signature));
  g_dbus_proxy_call (G_DBUS_PROXY (object),
    "org.freedesktop.DBus.Properties.Set",
    g_variant_new ("(ssv)", "org.freedesktop.UPower.Device", info->parent_struct.name, variant),
    G_DBUS_CALL_FLAGS_NONE,
    -1,
    NULL, (GAsyncReadyCallback) gf_upower_device_gen_proxy_set_property_cb, (GDBusPropertyInfo *) &info->parent_struct);
  g_variant_unref (variant);
}

static void
gf_upower_device_gen_proxy_g_signal (GDBusProxy *proxy,
  const gchar *sender_name G_GNUC_UNUSED,
  const gchar *signal_name,
  GVariant *parameters)
{
  _ExtendedGDBusSignalInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  gsize num_params;
  gsize n;
  guint signal_id;
  info = (_ExtendedGDBusSignalInfo *) g_dbus_interface_info_lookup_signal ((GDBusInterfaceInfo *) &_gf_upower_device_gen_interface_info.parent_struct, signal_name);
  if (info == NULL)
    return;
  num_params = g_variant_n_children (parameters);
  paramv = g_new0 (GValue, num_params + 1);
  g_value_init (&paramv[0], GF_TYPE_UPOWER_DEVICE_GEN);
  g_value_set_object (&paramv[0], proxy);
  g_variant_iter_init (&iter, parameters);
  n = 1;
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.args[n - 1];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, GF_TYPE_UPOWER_DEVICE_GEN);
  g_signal_emitv (paramv, signal_id, 0, NULL);
  for (n = 0; n < num_params + 1; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static void
gf_upower_device_gen_proxy_g_properties_changed (GDBusProxy *_proxy,
  GVariant *changed_properties,
  const gchar *const *invalidated_properties)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (_proxy);
  guint n;
  const gchar *key;
  GVariantIter *iter;
  _ExtendedGDBusPropertyInfo *info;
  g_variant_get (changed_properties, "a{sv}", &iter);
  while (g_variant_iter_next (iter, "{&sv}", &key, NULL))
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gf_upower_device_gen_interface_info.parent_struct, key);
      g_datalist_remove_data (&proxy->priv->qdata, key);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
  g_variant_iter_free (iter);
  for (n = 0; invalidated_properties[n] != NULL; n++)
    {
      info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gf_upower_device_gen_interface_info.parent_struct, invalidated_properties[n]);
      g_datalist_remove_data (&proxy->priv->qdata, invalidated_properties[n]);
      if (info != NULL)
        g_object_notify (G_OBJECT (proxy), info->hyphen_name);
    }
}

static const gchar *
gf_upower_device_gen_proxy_get_native_path (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "NativePath");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
gf_upower_device_gen_proxy_get_vendor (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Vendor");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
gf_upower_device_gen_proxy_get_model (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Model");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
gf_upower_device_gen_proxy_get_serial (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Serial");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static guint64 
gf_upower_device_gen_proxy_get_update_time (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  guint64 value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "UpdateTime");
  if (variant != NULL)
    {
      value = g_variant_get_uint64 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint 
gf_upower_device_gen_proxy_get_type_ (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  guint value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Type");
  if (variant != NULL)
    {
      value = g_variant_get_uint32 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
gf_upower_device_gen_proxy_get_power_supply (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gboolean value = FALSE;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "PowerSupply");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
gf_upower_device_gen_proxy_get_has_history (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gboolean value = FALSE;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "HasHistory");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
gf_upower_device_gen_proxy_get_has_statistics (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gboolean value = FALSE;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "HasStatistics");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
gf_upower_device_gen_proxy_get_online (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gboolean value = FALSE;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Online");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_energy (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Energy");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_energy_empty (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "EnergyEmpty");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_energy_full (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "EnergyFull");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_energy_full_design (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "EnergyFullDesign");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_energy_rate (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "EnergyRate");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_voltage (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Voltage");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_luminosity (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Luminosity");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gint64 
gf_upower_device_gen_proxy_get_time_to_empty (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gint64 value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "TimeToEmpty");
  if (variant != NULL)
    {
      value = g_variant_get_int64 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gint64 
gf_upower_device_gen_proxy_get_time_to_full (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gint64 value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "TimeToFull");
  if (variant != NULL)
    {
      value = g_variant_get_int64 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_percentage (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Percentage");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_temperature (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Temperature");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
gf_upower_device_gen_proxy_get_is_present (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gboolean value = FALSE;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "IsPresent");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint 
gf_upower_device_gen_proxy_get_state (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  guint value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "State");
  if (variant != NULL)
    {
      value = g_variant_get_uint32 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gboolean 
gf_upower_device_gen_proxy_get_is_rechargeable (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gboolean value = FALSE;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "IsRechargeable");
  if (variant != NULL)
    {
      value = g_variant_get_boolean (variant);
      g_variant_unref (variant);
    }
  return value;
}

static gdouble 
gf_upower_device_gen_proxy_get_capacity (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  gdouble value = 0.0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Capacity");
  if (variant != NULL)
    {
      value = g_variant_get_double (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint 
gf_upower_device_gen_proxy_get_technology (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  guint value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "Technology");
  if (variant != NULL)
    {
      value = g_variant_get_uint32 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static guint 
gf_upower_device_gen_proxy_get_warning_level (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  guint value = 0;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "WarningLevel");
  if (variant != NULL)
    {
      value = g_variant_get_uint32 (variant);
      g_variant_unref (variant);
    }
  return value;
}

static const gchar *
gf_upower_device_gen_proxy_get_icon_name (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenProxy *proxy = GF_UPOWER_DEVICE_GEN_PROXY (object);
  GVariant *variant;
  const gchar *value = NULL;
  variant = g_dbus_proxy_get_cached_property (G_DBUS_PROXY (proxy), "IconName");
  if (variant != NULL)
    {
      value = g_variant_get_string (variant, NULL);
      g_variant_unref (variant);
    }
  return value;
}

static void
gf_upower_device_gen_proxy_init (GfUPowerDeviceGenProxy *proxy)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  proxy->priv = gf_upower_device_gen_proxy_get_instance_private (proxy);
#else
  proxy->priv = G_TYPE_INSTANCE_GET_PRIVATE (proxy, GF_TYPE_UPOWER_DEVICE_GEN_PROXY, GfUPowerDeviceGenProxyPrivate);
#endif

  g_dbus_proxy_set_interface_info (G_DBUS_PROXY (proxy), gf_upower_device_gen_interface_info ());
}

static void
gf_upower_device_gen_proxy_class_init (GfUPowerDeviceGenProxyClass *klass)
{
  GObjectClass *gobject_class;
  GDBusProxyClass *proxy_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize     = gf_upower_device_gen_proxy_finalize;
  gobject_class->get_property = gf_upower_device_gen_proxy_get_property;
  gobject_class->set_property = gf_upower_device_gen_proxy_set_property;

  proxy_class = G_DBUS_PROXY_CLASS (klass);
  proxy_class->g_signal = gf_upower_device_gen_proxy_g_signal;
  proxy_class->g_properties_changed = gf_upower_device_gen_proxy_g_properties_changed;

  gf_upower_device_gen_override_properties (gobject_class, 1);

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (GfUPowerDeviceGenProxyPrivate));
#endif
}

static void
gf_upower_device_gen_proxy_iface_init (GfUPowerDeviceGenIface *iface)
{
  iface->get_native_path = gf_upower_device_gen_proxy_get_native_path;
  iface->get_vendor = gf_upower_device_gen_proxy_get_vendor;
  iface->get_model = gf_upower_device_gen_proxy_get_model;
  iface->get_serial = gf_upower_device_gen_proxy_get_serial;
  iface->get_update_time = gf_upower_device_gen_proxy_get_update_time;
  iface->get_type_ = gf_upower_device_gen_proxy_get_type_;
  iface->get_power_supply = gf_upower_device_gen_proxy_get_power_supply;
  iface->get_has_history = gf_upower_device_gen_proxy_get_has_history;
  iface->get_has_statistics = gf_upower_device_gen_proxy_get_has_statistics;
  iface->get_online = gf_upower_device_gen_proxy_get_online;
  iface->get_energy = gf_upower_device_gen_proxy_get_energy;
  iface->get_energy_empty = gf_upower_device_gen_proxy_get_energy_empty;
  iface->get_energy_full = gf_upower_device_gen_proxy_get_energy_full;
  iface->get_energy_full_design = gf_upower_device_gen_proxy_get_energy_full_design;
  iface->get_energy_rate = gf_upower_device_gen_proxy_get_energy_rate;
  iface->get_voltage = gf_upower_device_gen_proxy_get_voltage;
  iface->get_luminosity = gf_upower_device_gen_proxy_get_luminosity;
  iface->get_time_to_empty = gf_upower_device_gen_proxy_get_time_to_empty;
  iface->get_time_to_full = gf_upower_device_gen_proxy_get_time_to_full;
  iface->get_percentage = gf_upower_device_gen_proxy_get_percentage;
  iface->get_temperature = gf_upower_device_gen_proxy_get_temperature;
  iface->get_is_present = gf_upower_device_gen_proxy_get_is_present;
  iface->get_state = gf_upower_device_gen_proxy_get_state;
  iface->get_is_rechargeable = gf_upower_device_gen_proxy_get_is_rechargeable;
  iface->get_capacity = gf_upower_device_gen_proxy_get_capacity;
  iface->get_technology = gf_upower_device_gen_proxy_get_technology;
  iface->get_warning_level = gf_upower_device_gen_proxy_get_warning_level;
  iface->get_icon_name = gf_upower_device_gen_proxy_get_icon_name;
}

/**
 * gf_upower_device_gen_proxy_new:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (nullable): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Asynchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-UPower-Device.top_of_page">org.freedesktop.UPower.Device</link>. See g_dbus_proxy_new() for more details.
 *
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call gf_upower_device_gen_proxy_new_finish() to get the result of the operation.
 *
 * See gf_upower_device_gen_proxy_new_sync() for the synchronous, blocking version of this constructor.
 */
void
gf_upower_device_gen_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (GF_TYPE_UPOWER_DEVICE_GEN_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.freedesktop.UPower.Device", NULL);
}

/**
 * gf_upower_device_gen_proxy_new_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gf_upower_device_gen_proxy_new().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with gf_upower_device_gen_proxy_new().
 *
 * Returns: (transfer full) (type GfUPowerDeviceGenProxy): The constructed proxy object or %NULL if @error is set.
 */
GfUPowerDeviceGen *
gf_upower_device_gen_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return GF_UPOWER_DEVICE_GEN (ret);
  else
    return NULL;
}

/**
 * gf_upower_device_gen_proxy_new_sync:
 * @connection: A #GDBusConnection.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: (nullable): A bus name (well-known or unique) or %NULL if @connection is not a message bus connection.
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Synchronously creates a proxy for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-UPower-Device.top_of_page">org.freedesktop.UPower.Device</link>. See g_dbus_proxy_new_sync() for more details.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See gf_upower_device_gen_proxy_new() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type GfUPowerDeviceGenProxy): The constructed proxy object or %NULL if @error is set.
 */
GfUPowerDeviceGen *
gf_upower_device_gen_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (GF_TYPE_UPOWER_DEVICE_GEN_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-connection", connection, "g-object-path", object_path, "g-interface-name", "org.freedesktop.UPower.Device", NULL);
  if (ret != NULL)
    return GF_UPOWER_DEVICE_GEN (ret);
  else
    return NULL;
}


/**
 * gf_upower_device_gen_proxy_new_for_bus:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @callback: A #GAsyncReadyCallback to call when the request is satisfied.
 * @user_data: User data to pass to @callback.
 *
 * Like gf_upower_device_gen_proxy_new() but takes a #GBusType instead of a #GDBusConnection.
 *
 * When the operation is finished, @callback will be invoked in the thread-default main loop of the thread you are calling this method from (see g_main_context_push_thread_default()).
 * You can then call gf_upower_device_gen_proxy_new_for_bus_finish() to get the result of the operation.
 *
 * See gf_upower_device_gen_proxy_new_for_bus_sync() for the synchronous, blocking version of this constructor.
 */
void
gf_upower_device_gen_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data)
{
  g_async_initable_new_async (GF_TYPE_UPOWER_DEVICE_GEN_PROXY, G_PRIORITY_DEFAULT, cancellable, callback, user_data, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.freedesktop.UPower.Device", NULL);
}

/**
 * gf_upower_device_gen_proxy_new_for_bus_finish:
 * @res: The #GAsyncResult obtained from the #GAsyncReadyCallback passed to gf_upower_device_gen_proxy_new_for_bus().
 * @error: Return location for error or %NULL
 *
 * Finishes an operation started with gf_upower_device_gen_proxy_new_for_bus().
 *
 * Returns: (transfer full) (type GfUPowerDeviceGenProxy): The constructed proxy object or %NULL if @error is set.
 */
GfUPowerDeviceGen *
gf_upower_device_gen_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error)
{
  GObject *ret;
  GObject *source_object;
  source_object = g_async_result_get_source_object (res);
  ret = g_async_initable_new_finish (G_ASYNC_INITABLE (source_object), res, error);
  g_object_unref (source_object);
  if (ret != NULL)
    return GF_UPOWER_DEVICE_GEN (ret);
  else
    return NULL;
}

/**
 * gf_upower_device_gen_proxy_new_for_bus_sync:
 * @bus_type: A #GBusType.
 * @flags: Flags from the #GDBusProxyFlags enumeration.
 * @name: A bus name (well-known or unique).
 * @object_path: An object path.
 * @cancellable: (nullable): A #GCancellable or %NULL.
 * @error: Return location for error or %NULL
 *
 * Like gf_upower_device_gen_proxy_new_sync() but takes a #GBusType instead of a #GDBusConnection.
 *
 * The calling thread is blocked until a reply is received.
 *
 * See gf_upower_device_gen_proxy_new_for_bus() for the asynchronous version of this constructor.
 *
 * Returns: (transfer full) (type GfUPowerDeviceGenProxy): The constructed proxy object or %NULL if @error is set.
 */
GfUPowerDeviceGen *
gf_upower_device_gen_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error)
{
  GInitable *ret;
  ret = g_initable_new (GF_TYPE_UPOWER_DEVICE_GEN_PROXY, cancellable, error, "g-flags", flags, "g-name", name, "g-bus-type", bus_type, "g-object-path", object_path, "g-interface-name", "org.freedesktop.UPower.Device", NULL);
  if (ret != NULL)
    return GF_UPOWER_DEVICE_GEN (ret);
  else
    return NULL;
}


/* ------------------------------------------------------------------------ */

/**
 * GfUPowerDeviceGenSkeleton:
 *
 * The #GfUPowerDeviceGenSkeleton structure contains only private data and should only be accessed using the provided API.
 */

/**
 * GfUPowerDeviceGenSkeletonClass:
 * @parent_class: The parent class.
 *
 * Class structure for #GfUPowerDeviceGenSkeleton.
 */

struct _GfUPowerDeviceGenSkeletonPrivate
{
  GValue *properties;
  GList *changed_properties;
  GSource *changed_properties_idle_source;
  GMainContext *context;
  GMutex lock;
};

static void
_gf_upower_device_gen_skeleton_handle_method_call (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name,
  const gchar *method_name,
  GVariant *parameters,
  GDBusMethodInvocation *invocation,
  gpointer user_data)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (user_data);
  _ExtendedGDBusMethodInfo *info;
  GVariantIter iter;
  GVariant *child;
  GValue *paramv;
  gsize num_params;
  guint num_extra;
  gsize n;
  guint signal_id;
  GValue return_value = G_VALUE_INIT;
  info = (_ExtendedGDBusMethodInfo *) g_dbus_method_invocation_get_method_info (invocation);
  g_assert (info != NULL);
  num_params = g_variant_n_children (parameters);
  num_extra = info->pass_fdlist ? 3 : 2;  paramv = g_new0 (GValue, num_params + num_extra);
  n = 0;
  g_value_init (&paramv[n], GF_TYPE_UPOWER_DEVICE_GEN);
  g_value_set_object (&paramv[n++], skeleton);
  g_value_init (&paramv[n], G_TYPE_DBUS_METHOD_INVOCATION);
  g_value_set_object (&paramv[n++], invocation);
  if (info->pass_fdlist)
    {
#ifdef G_OS_UNIX
      g_value_init (&paramv[n], G_TYPE_UNIX_FD_LIST);
      g_value_set_object (&paramv[n++], g_dbus_message_get_unix_fd_list (g_dbus_method_invocation_get_message (invocation)));
#else
      g_assert_not_reached ();
#endif
    }
  g_variant_iter_init (&iter, parameters);
  while ((child = g_variant_iter_next_value (&iter)) != NULL)
    {
      _ExtendedGDBusArgInfo *arg_info = (_ExtendedGDBusArgInfo *) info->parent_struct.in_args[n - num_extra];
      if (arg_info->use_gvariant)
        {
          g_value_init (&paramv[n], G_TYPE_VARIANT);
          g_value_set_variant (&paramv[n], child);
          n++;
        }
      else
        g_dbus_gvariant_to_gvalue (child, &paramv[n++]);
      g_variant_unref (child);
    }
  signal_id = g_signal_lookup (info->signal_name, GF_TYPE_UPOWER_DEVICE_GEN);
  g_value_init (&return_value, G_TYPE_BOOLEAN);
  g_signal_emitv (paramv, signal_id, 0, &return_value);
  if (!g_value_get_boolean (&return_value))
    g_dbus_method_invocation_return_error (invocation, G_DBUS_ERROR, G_DBUS_ERROR_UNKNOWN_METHOD, "Method %s is not implemented on interface %s", method_name, interface_name);
  g_value_unset (&return_value);
  for (n = 0; n < num_params + num_extra; n++)
    g_value_unset (&paramv[n]);
  g_free (paramv);
}

static GVariant *
_gf_upower_device_gen_skeleton_handle_get_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GError **error,
  gpointer user_data)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  GVariant *ret;
  ret = NULL;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gf_upower_device_gen_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      g_value_init (&value, pspec->value_type);
      g_object_get_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      ret = g_dbus_gvalue_to_gvariant (&value, G_VARIANT_TYPE (info->parent_struct.signature));
      g_value_unset (&value);
    }
  return ret;
}

static gboolean
_gf_upower_device_gen_skeleton_handle_set_property (
  GDBusConnection *connection G_GNUC_UNUSED,
  const gchar *sender G_GNUC_UNUSED,
  const gchar *object_path G_GNUC_UNUSED,
  const gchar *interface_name G_GNUC_UNUSED,
  const gchar *property_name,
  GVariant *variant,
  GError **error,
  gpointer user_data)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (user_data);
  GValue value = G_VALUE_INIT;
  GParamSpec *pspec;
  _ExtendedGDBusPropertyInfo *info;
  gboolean ret;
  ret = FALSE;
  info = (_ExtendedGDBusPropertyInfo *) g_dbus_interface_info_lookup_property ((GDBusInterfaceInfo *) &_gf_upower_device_gen_interface_info.parent_struct, property_name);
  g_assert (info != NULL);
  pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (skeleton), info->hyphen_name);
  if (pspec == NULL)
    {
      g_set_error (error, G_DBUS_ERROR, G_DBUS_ERROR_INVALID_ARGS, "No property with name %s", property_name);
    }
  else
    {
      if (info->use_gvariant)
        g_value_set_variant (&value, variant);
      else
        g_dbus_gvariant_to_gvalue (variant, &value);
      g_object_set_property (G_OBJECT (skeleton), info->hyphen_name, &value);
      g_value_unset (&value);
      ret = TRUE;
    }
  return ret;
}

static const GDBusInterfaceVTable _gf_upower_device_gen_skeleton_vtable =
{
  _gf_upower_device_gen_skeleton_handle_method_call,
  _gf_upower_device_gen_skeleton_handle_get_property,
  _gf_upower_device_gen_skeleton_handle_set_property,
  {NULL}
};

static GDBusInterfaceInfo *
gf_upower_device_gen_skeleton_dbus_interface_get_info (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return gf_upower_device_gen_interface_info ();
}

static GDBusInterfaceVTable *
gf_upower_device_gen_skeleton_dbus_interface_get_vtable (GDBusInterfaceSkeleton *skeleton G_GNUC_UNUSED)
{
  return (GDBusInterfaceVTable *) &_gf_upower_device_gen_skeleton_vtable;
}

static GVariant *
gf_upower_device_gen_skeleton_dbus_interface_get_properties (GDBusInterfaceSkeleton *_skeleton)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (_skeleton);

  GVariantBuilder builder;
  guint n;
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_84
  g_variant_builder_init_static (&builder, G_VARIANT_TYPE ("a{sv}"));
#else
  g_variant_builder_init(&builder, G_VARIANT_TYPE ("a{sv}"));
#endif
  if (_gf_upower_device_gen_interface_info.parent_struct.properties == NULL)
    goto out;
  for (n = 0; _gf_upower_device_gen_interface_info.parent_struct.properties[n] != NULL; n++)
    {
      GDBusPropertyInfo *info = _gf_upower_device_gen_interface_info.parent_struct.properties[n];
      if (info->flags & G_DBUS_PROPERTY_INFO_FLAGS_READABLE)
        {
          GVariant *value;
          value = _gf_upower_device_gen_skeleton_handle_get_property (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)), NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)), "org.freedesktop.UPower.Device", info->name, NULL, skeleton);
          if (value != NULL)
            {
              g_variant_take_ref (value);
              g_variant_builder_add (&builder, "{sv}", info->name, value);
              g_variant_unref (value);
            }
        }
    }
out:
  return g_variant_builder_end (&builder);
}

static gboolean _gf_upower_device_gen_emit_changed (gpointer user_data);

static void
gf_upower_device_gen_skeleton_dbus_interface_flush (GDBusInterfaceSkeleton *_skeleton)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (_skeleton);
  gboolean emit_changed = FALSE;

  g_mutex_lock (&skeleton->priv->lock);
  if (skeleton->priv->changed_properties_idle_source != NULL)
    {
      g_source_destroy (skeleton->priv->changed_properties_idle_source);
      skeleton->priv->changed_properties_idle_source = NULL;
      emit_changed = TRUE;
    }
  g_mutex_unlock (&skeleton->priv->lock);

  if (emit_changed)
    _gf_upower_device_gen_emit_changed (skeleton);
}

static void gf_upower_device_gen_skeleton_iface_init (GfUPowerDeviceGenIface *iface);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
G_DEFINE_TYPE_WITH_CODE (GfUPowerDeviceGenSkeleton, gf_upower_device_gen_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_ADD_PRIVATE (GfUPowerDeviceGenSkeleton)
                         G_IMPLEMENT_INTERFACE (GF_TYPE_UPOWER_DEVICE_GEN, gf_upower_device_gen_skeleton_iface_init))

#else
G_DEFINE_TYPE_WITH_CODE (GfUPowerDeviceGenSkeleton, gf_upower_device_gen_skeleton, G_TYPE_DBUS_INTERFACE_SKELETON,
                         G_IMPLEMENT_INTERFACE (GF_TYPE_UPOWER_DEVICE_GEN, gf_upower_device_gen_skeleton_iface_init))

#endif
static void
gf_upower_device_gen_skeleton_finalize (GObject *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  guint n;
  for (n = 0; n < 28; n++)
    g_value_unset (&skeleton->priv->properties[n]);
  g_free (skeleton->priv->properties);
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
  if (skeleton->priv->changed_properties_idle_source != NULL)
    g_source_destroy (skeleton->priv->changed_properties_idle_source);
  g_main_context_unref (skeleton->priv->context);
  g_mutex_clear (&skeleton->priv->lock);
  G_OBJECT_CLASS (gf_upower_device_gen_skeleton_parent_class)->finalize (object);
}

static void
gf_upower_device_gen_skeleton_get_property (GObject      *object,
  guint         prop_id,
  GValue       *value,
  GParamSpec   *pspec G_GNUC_UNUSED)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  g_assert (prop_id != 0 && prop_id - 1 < 28);
  g_mutex_lock (&skeleton->priv->lock);
  g_value_copy (&skeleton->priv->properties[prop_id - 1], value);
  g_mutex_unlock (&skeleton->priv->lock);
}

static gboolean
_gf_upower_device_gen_emit_changed (gpointer user_data)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (user_data);
  GList *l;
  GVariantBuilder builder;
  GVariantBuilder invalidated_builder;
  guint num_changes;

  g_mutex_lock (&skeleton->priv->lock);
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_84
  g_variant_builder_init_static (&builder, G_VARIANT_TYPE ("a{sv}"));
  g_variant_builder_init_static (&invalidated_builder, G_VARIANT_TYPE ("as"));
#else
  g_variant_builder_init (&builder, G_VARIANT_TYPE ("a{sv}"));
  g_variant_builder_init (&invalidated_builder, G_VARIANT_TYPE ("as"));
#endif
  for (l = skeleton->priv->changed_properties, num_changes = 0; l != NULL; l = l->next)
    {
      ChangedProperty *cp = l->data;
      GVariant *variant;
      const GValue *cur_value;

      cur_value = &skeleton->priv->properties[cp->prop_id - 1];
      if (!_g_value_equal (cur_value, &cp->orig_value))
        {
          variant = g_dbus_gvalue_to_gvariant (cur_value, G_VARIANT_TYPE (cp->info->parent_struct.signature));
          g_variant_builder_add (&builder, "{sv}", cp->info->parent_struct.name, variant);
          g_variant_unref (variant);
          num_changes++;
        }
    }
  if (num_changes > 0)
    {
      GList *connections, *ll;
      GVariant *signal_variant;
      signal_variant = g_variant_ref_sink (g_variant_new ("(sa{sv}as)", "org.freedesktop.UPower.Device",
                                           &builder, &invalidated_builder));
      connections = g_dbus_interface_skeleton_get_connections (G_DBUS_INTERFACE_SKELETON (skeleton));
      for (ll = connections; ll != NULL; ll = ll->next)
        {
          GDBusConnection *connection = ll->data;

          g_dbus_connection_emit_signal (connection,
                                         NULL, g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (skeleton)),
                                         "org.freedesktop.DBus.Properties",
                                         "PropertiesChanged",
                                         signal_variant,
                                         NULL);
        }
      g_variant_unref (signal_variant);
      g_list_free_full (connections, g_object_unref);
    }
  else
    {
      g_variant_builder_clear (&builder);
      g_variant_builder_clear (&invalidated_builder);
    }
  g_list_free_full (skeleton->priv->changed_properties, (GDestroyNotify) _changed_property_free);
  skeleton->priv->changed_properties = NULL;
  skeleton->priv->changed_properties_idle_source = NULL;
  g_mutex_unlock (&skeleton->priv->lock);
  return FALSE;
}

static void
_gf_upower_device_gen_schedule_emit_changed (GfUPowerDeviceGenSkeleton *skeleton, const _ExtendedGDBusPropertyInfo *info, guint prop_id, const GValue *orig_value)
{
  ChangedProperty *cp;
  GList *l;
  cp = NULL;
  for (l = skeleton->priv->changed_properties; l != NULL; l = l->next)
    {
      ChangedProperty *i_cp = l->data;
      if (i_cp->info == info)
        {
          cp = i_cp;
          break;
        }
    }
  if (cp == NULL)
    {
      cp = g_new0 (ChangedProperty, 1);
      cp->prop_id = prop_id;
      cp->info = info;
      skeleton->priv->changed_properties = g_list_prepend (skeleton->priv->changed_properties, cp);
      g_value_init (&cp->orig_value, G_VALUE_TYPE (orig_value));
      g_value_copy (orig_value, &cp->orig_value);
    }
}

static void
gf_upower_device_gen_skeleton_notify (GObject      *object,
  GParamSpec *pspec G_GNUC_UNUSED)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  g_mutex_lock (&skeleton->priv->lock);
  if (skeleton->priv->changed_properties != NULL &&
      skeleton->priv->changed_properties_idle_source == NULL)
    {
      skeleton->priv->changed_properties_idle_source = g_idle_source_new ();
      g_source_set_priority (skeleton->priv->changed_properties_idle_source, G_PRIORITY_DEFAULT);
      g_source_set_callback (skeleton->priv->changed_properties_idle_source, _gf_upower_device_gen_emit_changed, g_object_ref (skeleton), (GDestroyNotify) g_object_unref);
      g_source_set_name (skeleton->priv->changed_properties_idle_source, "[generated] _gf_upower_device_gen_emit_changed");
      g_source_attach (skeleton->priv->changed_properties_idle_source, skeleton->priv->context);
      g_source_unref (skeleton->priv->changed_properties_idle_source);
    }
  g_mutex_unlock (&skeleton->priv->lock);
}

static void
gf_upower_device_gen_skeleton_set_property (GObject      *object,
  guint         prop_id,
  const GValue *value,
  GParamSpec   *pspec)
{
  const _ExtendedGDBusPropertyInfo *info;
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  g_assert (prop_id != 0 && prop_id - 1 < 28);
  info = (const _ExtendedGDBusPropertyInfo *) _gf_upower_device_gen_property_info_pointers[prop_id - 1];
  g_mutex_lock (&skeleton->priv->lock);
  g_object_freeze_notify (object);
  if (!_g_value_equal (value, &skeleton->priv->properties[prop_id - 1]))
    {
      if (g_dbus_interface_skeleton_get_connection (G_DBUS_INTERFACE_SKELETON (skeleton)) != NULL &&
          info->emits_changed_signal)
        _gf_upower_device_gen_schedule_emit_changed (skeleton, info, prop_id, &skeleton->priv->properties[prop_id - 1]);
      g_value_copy (value, &skeleton->priv->properties[prop_id - 1]);
      g_object_notify_by_pspec (object, pspec);
    }
  g_mutex_unlock (&skeleton->priv->lock);
  g_object_thaw_notify (object);
}

static void
gf_upower_device_gen_skeleton_init (GfUPowerDeviceGenSkeleton *skeleton)
{
#if GLIB_VERSION_MAX_ALLOWED >= GLIB_VERSION_2_38
  skeleton->priv = gf_upower_device_gen_skeleton_get_instance_private (skeleton);
#else
  skeleton->priv = G_TYPE_INSTANCE_GET_PRIVATE (skeleton, GF_TYPE_UPOWER_DEVICE_GEN_SKELETON, GfUPowerDeviceGenSkeletonPrivate);
#endif

  g_mutex_init (&skeleton->priv->lock);
  skeleton->priv->context = g_main_context_ref_thread_default ();
  skeleton->priv->properties = g_new0 (GValue, 28);
  g_value_init (&skeleton->priv->properties[0], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[1], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[2], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[3], G_TYPE_STRING);
  g_value_init (&skeleton->priv->properties[4], G_TYPE_UINT64);
  g_value_init (&skeleton->priv->properties[5], G_TYPE_UINT);
  g_value_init (&skeleton->priv->properties[6], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[7], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[8], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[9], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[10], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[11], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[12], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[13], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[14], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[15], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[16], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[17], G_TYPE_INT64);
  g_value_init (&skeleton->priv->properties[18], G_TYPE_INT64);
  g_value_init (&skeleton->priv->properties[19], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[20], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[21], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[22], G_TYPE_UINT);
  g_value_init (&skeleton->priv->properties[23], G_TYPE_BOOLEAN);
  g_value_init (&skeleton->priv->properties[24], G_TYPE_DOUBLE);
  g_value_init (&skeleton->priv->properties[25], G_TYPE_UINT);
  g_value_init (&skeleton->priv->properties[26], G_TYPE_UINT);
  g_value_init (&skeleton->priv->properties[27], G_TYPE_STRING);
}

static const gchar *
gf_upower_device_gen_skeleton_get_native_path (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_string (&(skeleton->priv->properties[0]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
gf_upower_device_gen_skeleton_get_vendor (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_string (&(skeleton->priv->properties[1]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
gf_upower_device_gen_skeleton_get_model (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_string (&(skeleton->priv->properties[2]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
gf_upower_device_gen_skeleton_get_serial (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_string (&(skeleton->priv->properties[3]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint64 
gf_upower_device_gen_skeleton_get_update_time (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  guint64 value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_uint64 (&(skeleton->priv->properties[4]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint 
gf_upower_device_gen_skeleton_get_type_ (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  guint value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_uint (&(skeleton->priv->properties[5]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
gf_upower_device_gen_skeleton_get_power_supply (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_boolean (&(skeleton->priv->properties[6]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
gf_upower_device_gen_skeleton_get_has_history (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_boolean (&(skeleton->priv->properties[7]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
gf_upower_device_gen_skeleton_get_has_statistics (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_boolean (&(skeleton->priv->properties[8]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
gf_upower_device_gen_skeleton_get_online (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_boolean (&(skeleton->priv->properties[9]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_energy (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[10]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_energy_empty (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[11]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_energy_full (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[12]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_energy_full_design (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[13]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_energy_rate (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[14]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_voltage (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[15]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_luminosity (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[16]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gint64 
gf_upower_device_gen_skeleton_get_time_to_empty (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gint64 value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_int64 (&(skeleton->priv->properties[17]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gint64 
gf_upower_device_gen_skeleton_get_time_to_full (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gint64 value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_int64 (&(skeleton->priv->properties[18]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_percentage (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[19]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_temperature (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[20]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
gf_upower_device_gen_skeleton_get_is_present (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_boolean (&(skeleton->priv->properties[21]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint 
gf_upower_device_gen_skeleton_get_state (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  guint value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_uint (&(skeleton->priv->properties[22]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gboolean 
gf_upower_device_gen_skeleton_get_is_rechargeable (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gboolean value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_boolean (&(skeleton->priv->properties[23]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static gdouble 
gf_upower_device_gen_skeleton_get_capacity (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  gdouble value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_double (&(skeleton->priv->properties[24]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint 
gf_upower_device_gen_skeleton_get_technology (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  guint value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_uint (&(skeleton->priv->properties[25]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static guint 
gf_upower_device_gen_skeleton_get_warning_level (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  guint value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_uint (&(skeleton->priv->properties[26]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static const gchar *
gf_upower_device_gen_skeleton_get_icon_name (GfUPowerDeviceGen *object)
{
  GfUPowerDeviceGenSkeleton *skeleton = GF_UPOWER_DEVICE_GEN_SKELETON (object);
  const gchar *value;
  g_mutex_lock (&skeleton->priv->lock);
  value = g_marshal_value_peek_string (&(skeleton->priv->properties[27]));
  g_mutex_unlock (&skeleton->priv->lock);
  return value;
}

static void
gf_upower_device_gen_skeleton_class_init (GfUPowerDeviceGenSkeletonClass *klass)
{
  GObjectClass *gobject_class;
  GDBusInterfaceSkeletonClass *skeleton_class;

  gobject_class = G_OBJECT_CLASS (klass);
  gobject_class->finalize = gf_upower_device_gen_skeleton_finalize;
  gobject_class->get_property = gf_upower_device_gen_skeleton_get_property;
  gobject_class->set_property = gf_upower_device_gen_skeleton_set_property;
  gobject_class->notify       = gf_upower_device_gen_skeleton_notify;


  gf_upower_device_gen_override_properties (gobject_class, 1);

  skeleton_class = G_DBUS_INTERFACE_SKELETON_CLASS (klass);
  skeleton_class->get_info = gf_upower_device_gen_skeleton_dbus_interface_get_info;
  skeleton_class->get_properties = gf_upower_device_gen_skeleton_dbus_interface_get_properties;
  skeleton_class->flush = gf_upower_device_gen_skeleton_dbus_interface_flush;
  skeleton_class->get_vtable = gf_upower_device_gen_skeleton_dbus_interface_get_vtable;

#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_38
  g_type_class_add_private (klass, sizeof (GfUPowerDeviceGenSkeletonPrivate));
#endif
}

static void
gf_upower_device_gen_skeleton_iface_init (GfUPowerDeviceGenIface *iface)
{
  iface->get_native_path = gf_upower_device_gen_skeleton_get_native_path;
  iface->get_vendor = gf_upower_device_gen_skeleton_get_vendor;
  iface->get_model = gf_upower_device_gen_skeleton_get_model;
  iface->get_serial = gf_upower_device_gen_skeleton_get_serial;
  iface->get_update_time = gf_upower_device_gen_skeleton_get_update_time;
  iface->get_type_ = gf_upower_device_gen_skeleton_get_type_;
  iface->get_power_supply = gf_upower_device_gen_skeleton_get_power_supply;
  iface->get_has_history = gf_upower_device_gen_skeleton_get_has_history;
  iface->get_has_statistics = gf_upower_device_gen_skeleton_get_has_statistics;
  iface->get_online = gf_upower_device_gen_skeleton_get_online;
  iface->get_energy = gf_upower_device_gen_skeleton_get_energy;
  iface->get_energy_empty = gf_upower_device_gen_skeleton_get_energy_empty;
  iface->get_energy_full = gf_upower_device_gen_skeleton_get_energy_full;
  iface->get_energy_full_design = gf_upower_device_gen_skeleton_get_energy_full_design;
  iface->get_energy_rate = gf_upower_device_gen_skeleton_get_energy_rate;
  iface->get_voltage = gf_upower_device_gen_skeleton_get_voltage;
  iface->get_luminosity = gf_upower_device_gen_skeleton_get_luminosity;
  iface->get_time_to_empty = gf_upower_device_gen_skeleton_get_time_to_empty;
  iface->get_time_to_full = gf_upower_device_gen_skeleton_get_time_to_full;
  iface->get_percentage = gf_upower_device_gen_skeleton_get_percentage;
  iface->get_temperature = gf_upower_device_gen_skeleton_get_temperature;
  iface->get_is_present = gf_upower_device_gen_skeleton_get_is_present;
  iface->get_state = gf_upower_device_gen_skeleton_get_state;
  iface->get_is_rechargeable = gf_upower_device_gen_skeleton_get_is_rechargeable;
  iface->get_capacity = gf_upower_device_gen_skeleton_get_capacity;
  iface->get_technology = gf_upower_device_gen_skeleton_get_technology;
  iface->get_warning_level = gf_upower_device_gen_skeleton_get_warning_level;
  iface->get_icon_name = gf_upower_device_gen_skeleton_get_icon_name;
}

/**
 * gf_upower_device_gen_skeleton_new:
 *
 * Creates a skeleton object for the D-Bus interface <link linkend="gdbus-interface-org-freedesktop-UPower-Device.top_of_page">org.freedesktop.UPower.Device</link>.
 *
 * Returns: (transfer full) (type GfUPowerDeviceGenSkeleton): The skeleton object.
 */
GfUPowerDeviceGen *
gf_upower_device_gen_skeleton_new (void)
{
  return GF_UPOWER_DEVICE_GEN (g_object_new (GF_TYPE_UPOWER_DEVICE_GEN_SKELETON, NULL));
}

